FSM APIΒΆ
The finite-state-machine package contains state definitions, contexts, and storage implementations for memory and Redis-backed workflows.
Finite-state conversation support for Peyk. |
The finite-state-machine package contains state definitions, contexts, and storage implementations for memory and Redis-backed workflows.
Finite-state conversation support for Peyk. |